@@ -1,8 +1,12 @@
 fn main() {
+    if std::env::var_os("DOCS_RS").is_some() {
+        return;
+    }
+
     println!("cargo:rerun-if-changed=cpp/bindings.cpp");
 
     let mut cfg = cc::Build::new();
-    cfg.cpp(true).include("/cpp").file("cpp/bindings.cpp");
+    cfg.cpp(true).include("cpp").file("cpp/bindings.cpp");
 
     //PB10及以上版本
     cfg.define("UNICODE", None);
@@ -12,9 +16,7 @@ fn main() {
 
     cfg.compile("pbx");
 
-    if std::env::var("DOCS_RS").is_err() {
-        build_def();
-    }
+    build_def();
 }
 
 //生成导出符号定义文件
